Installation instructions — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- Programming guide »

# Installation instructions

pytilities can be installed using the standard PyPI installation procedure. If you don’t know how that works, then read on.

You have 2 options: either do a distutils installation, or use EasyInstall (or you might even find it with your os’ package manager, which is always the best choice).

## distutils

- Download the library from PyPI, and extract it.
- Continue with these instructions

## EasyInstall

See http://wiki.python.org/moin/EasyInstall

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- Programming guide »